<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>EllipseCPP</name>
    <message>
        <source>&amp;Full Ellipse</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Pełna elipsa</translation>
    </message>
    <message>
        <location filename="../EllipseCPPInit.js" line="+2"/>
        <source>&amp;Ellipse (Center, Point, Ratio)</source>
        <translation>&amp;Elipsa (środek, punkt, proporcja)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw full ellipse from center, major point and ratio</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje pełną elipsę od środka, przez punkt i o danej proporcji</translation>
    </message>
</context>
</TS>
